.. _recipe_asr.gs:

asr.gs
======


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.gs`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.gs.calculate`
  - :py:func:`asr.gs.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.gs

or as a python module

.. code-block:: console

   $ python -m asr.gs

Detailed description
--------------------
Electronic ground state properties.

Steps
-----


asr.gs@calculate
^^^^^^^^^^^^^^^^
.. autofunction:: asr.gs.calculate
   

asr.gs
^^^^^^
.. autofunction:: asr.gs.main
   